@@ -617,7 +617,7 @@ def run_gui(
                 gr.Markdown(
                     value="""* SPAR is a Python package and a web interface for measuring short text documents using semantic projection.
                     * The package is part of the manuscript ISR-2022-128 (under review). It is still considered a research prototype and under active development. 
-                    * The source code is available on [GitHub](https://github.com/ISR2022128/SPAR_measure) under GPLv3 license.""",
+                    * The source code is available on [GitHub](https://github.com/ISR-2022-128/SPAR_measure) under GPLv3 license.""",
                     label="",
                 )
         example_row = gr.Row(visible=False, variant="panel")
@@ -1065,17 +1065,10 @@ def run_gui(
             favicon_path=path_mgt.sample_data_dir / "favicon.png",
             **kwargs,
         )
-    elif mode == "intranet":
-        demo.launch(
-            server_name="0.0.0.0",
-            auth=auth,
-            favicon_path=path_mgt.sample_data_dir / "favicon.png",
-            **kwargs,
-        )
     elif mode == "local":
         demo.launch(favicon_path=path_mgt.sample_data_dir / "favicon.png", **kwargs)
     else:
-        print("Invalid mode. Please choose from 'public', 'intranet', or 'local'.")
+        print("Invalid mode. Please choose from 'public' or 'local'.")
 
 
 if __name__ == "__main__":
